==> eiffelstudio-18.11.10.2592.tar: F_code/C6/ei256.c <==
/*
 * Code for class EIFFEL_CONSTANTS
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ei256.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EIFFEL_CONSTANTS}.ise_eiffel_env */

EIF_REFERENCE F301_4082 (EIF_REFERENCE Current)
{
	GTCX
	RTOUC (50,RTMS_EX_H("ISE_EIFFEL",10,960687436));
}

/* {EIFFEL_CONSTANTS}.ise_library_env */

EIF_REFERENCE F301_4083 (EIF_REFERENCE Current)
{
	GTCX
	RTOUC (51,RTMS_EX_H("ISE_LIBRARY",11,552576601));
}

/* {EIFFEL_CONSTANTS}.eiffel_library_env */

EIF_REFERENCE F301_4084 (EIF_REFERENCE Current)
{
	GTCX
	RTOUC (52,RTMS_EX_H("EIFFEL_LIBRARY",14,1735641689));
}

/* {EIFFEL_CONSTANTS}.ise_iron_path_env */

EIF_REFERENCE F301_4085 (EIF_REFERENCE Current)
{
	GTCX
	RTOUC (53,RTMS_EX_H("ISE_IRON_PATH",13,591182408));
}

/* {EIFFEL_CONSTANTS}.iron_path_env */

EIF_REFERENCE F301_4086 (EIF_REFERENCE Current)
{
	GTCX
	RTOUC (54,RTMS_EX_H("IRON_PATH",9,490076488));
}

/* {EIFFEL_CONSTANTS}.ise_precomp_env */

EIF_REFERENCE F301_4087 (EIF_REFERENCE Current)
{
	GTCX
	RTOUC (55,RTMS_EX_H("ISE_PRECOMP",11,185338448));
}

/* {EIFFEL_CONSTANTS}.ise_platform_env */

EIF_REFERENCE F301_4088 (EIF_REFERENCE Current)
{
	GTCX
	RTOUC (56,RTMS_EX_H("ISE_PLATFORM",12,1318550605));
}

/* {EIFFEL_CONSTANTS}.ise_c_compiler_env */

EIF_REFERENCE F301_4089 (EIF_REFERENCE Current)
{
	GTCX
	RTOUC (57,RTMS_EX_H("ISE_C_COMPILER",14,1981921618));
}

/* {EIFFEL_CONSTANTS}.ise_user_files_env */

EIF_REFERENCE F301_4092 (EIF_REFERENCE Current)
{
	GTCX
	RTOUC (58,RTMS_EX_H("ISE_USER_FILES",14,1880819283));
}

/* {EIFFEL_CONSTANTS}.ise_app_data_env */

EIF_REFERENCE F301_4093 (EIF_REFERENCE Current)
{
	GTCX
	RTOUC (59,RTMS_EX_H("ISE_APP_DATA",12,1175984961));
}

/* {EIFFEL_CONSTANTS}.two_digit_minimum_major_version */
static EIF_REFERENCE F301_4100_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
#define Result RTOTRR
	RTOUDR(0)

	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEV;
	RTGC;
	RTOTP;
	ti4_1 = (EIF_INTEGER_32) ((EIF_NATURAL_16) 18U);
	Result = F301_4102(Current, ti4_1);
	RTOTE;
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F301_4100 (EIF_REFERENCE Current)
{
	GTCX
	return RTOUCR(0,F301_4100_body,(Current));
}

/* {EIFFEL_CONSTANTS}.two_digit_minimum_minor_version */
static EIF_REFERENCE F301_4101_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
#define Result RTOTRR
	RTOUDR(1)

	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEV;
	RTGC;
	RTOTP;
	ti4_1 = (EIF_INTEGER_32) ((EIF_NATURAL_16) 11U);
	Result = F301_4102(Current, ti4_1);
	RTOTE;
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F301_4101 (EIF_REFERENCE Current)
{
	GTCX
	return RTOUCR(1,F301_4101_body,(Current));
}

/* {EIFFEL_CONSTANTS}.two_digit_minimum_string */
EIF_REFERENCE F301_4102 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,tr1);
	RTLR(1,Result);
	RTLIU(2);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(1131, 0x01).id, 1131, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F1130_9883(RTCW(tr1), ((EIF_INTEGER_32) 2L));
	Result = (EIF_REFERENCE) tr1;
	if ((EIF_BOOLEAN) (arg1 < ((EIF_INTEGER_32) 10L))) {
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_CHARACTER_8)) R8443[Dtype(Result)-1131])(RTCW(Result), (EIF_CHARACTER_8) '0');
	}
	F1132_9998(RTCW(Result), arg1);
	RTLE;
	return Result;
}

void EIF_Minit256 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C6/ei256.c <==
/*
 * Code for class EIFFEL_CONSTANTS
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ei256.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EIFFEL_CONSTANTS}.ise_eiffel_env */

EIF_REFERENCE F301_4074 (EIF_REFERENCE Current)
{
	GTCX
	RTOUC (50,RTMS_EX_H("ISE_EIFFEL",10,960687436));
}

/* {EIFFEL_CONSTANTS}.ise_library_env */

EIF_REFERENCE F301_4075 (EIF_REFERENCE Current)
{
	GTCX
	RTOUC (51,RTMS_EX_H("ISE_LIBRARY",11,552576601));
}

/* {EIFFEL_CONSTANTS}.eiffel_library_env */

EIF_REFERENCE F301_4076 (EIF_REFERENCE Current)
{
	GTCX
	RTOUC (52,RTMS_EX_H("EIFFEL_LIBRARY",14,1735641689));
}

/* {EIFFEL_CONSTANTS}.ise_iron_path_env */

EIF_REFERENCE F301_4077 (EIF_REFERENCE Current)
{
	GTCX
	RTOUC (53,RTMS_EX_H("ISE_IRON_PATH",13,591182408));
}

/* {EIFFEL_CONSTANTS}.iron_path_env */

EIF_REFERENCE F301_4078 (EIF_REFERENCE Current)
{
	GTCX
	RTOUC (54,RTMS_EX_H("IRON_PATH",9,490076488));
}

/* {EIFFEL_CONSTANTS}.ise_precomp_env */

EIF_REFERENCE F301_4079 (EIF_REFERENCE Current)
{
	GTCX
	RTOUC (55,RTMS_EX_H("ISE_PRECOMP",11,185338448));
}

/* {EIFFEL_CONSTANTS}.ise_platform_env */

EIF_REFERENCE F301_4080 (EIF_REFERENCE Current)
{
	GTCX
	RTOUC (56,RTMS_EX_H("ISE_PLATFORM",12,1318550605));
}

/* {EIFFEL_CONSTANTS}.ise_c_compiler_env */

EIF_REFERENCE F301_4081 (EIF_REFERENCE Current)
{
	GTCX
	RTOUC (57,RTMS_EX_H("ISE_C_COMPILER",14,1981921618));
}

/* {EIFFEL_CONSTANTS}.ise_user_files_env */

EIF_REFERENCE F301_4084 (EIF_REFERENCE Current)
{
	GTCX
	RTOUC (58,RTMS_EX_H("ISE_USER_FILES",14,1880819283));
}

/* {EIFFEL_CONSTANTS}.ise_app_data_env */

EIF_REFERENCE F301_4085 (EIF_REFERENCE Current)
{
	GTCX
	RTOUC (59,RTMS_EX_H("ISE_APP_DATA",12,1175984961));
}

/* {EIFFEL_CONSTANTS}.two_digit_minimum_major_version */
static EIF_REFERENCE F301_4092_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
#define Result RTOTRR
	RTOUDR(0)

	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEV;
	RTGC;
	RTOTP;
	ti4_1 = (EIF_INTEGER_32) ((EIF_NATURAL_16) 19U);
	Result = F301_4094(Current, ti4_1);
	RTOTE;
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F301_4092 (EIF_REFERENCE Current)
{
	GTCX
	return RTOUCR(0,F301_4092_body,(Current));
}

/* {EIFFEL_CONSTANTS}.two_digit_minimum_minor_version */
static EIF_REFERENCE F301_4093_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
#define Result RTOTRR
	RTOUDR(1)

	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEV;
	RTGC;
	RTOTP;
	ti4_1 = (EIF_INTEGER_32) ((EIF_NATURAL_16) 5U);
	Result = F301_4094(Current, ti4_1);
	RTOTE;
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F301_4093 (EIF_REFERENCE Current)
{
	GTCX
	return RTOUCR(1,F301_4093_body,(Current));
}

/* {EIFFEL_CONSTANTS}.two_digit_minimum_string */
EIF_REFERENCE F301_4094 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Result);
	RTLIU(1);
	
	RTGC;
	Result = RTLNS(eif_new_type(1132, 0x01).id, 1132, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F1131_9906(RTCW(Result), ((EIF_INTEGER_32) 2L));
	if ((EIF_BOOLEAN) (arg1 < ((EIF_INTEGER_32) 10L))) {
		F1133_10031(RTCW(Result), (EIF_CHARACTER_8) '0');
	}
	F1133_10021(RTCW(Result), arg1);
	RTLE;
	return Result;
}

void EIF_Minit256 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
